@@ -582,7 +582,7 @@ class Sf:
         return await async_query(query, excludedFields)
     
     async def async_queries(self, queries: List[str]):
-        async_queries = async_wrap(self.sf.query)
+        async_queries = async_wrap(self.sf.query_all)
         result_list = await asyncio.gather(*[async_queries(query) for query in queries])
         result_pd_list = [transform_sf_result_set_rec(result['records']) for result in result_list]
         return result_pd_list
